@@ -17,6 +17,8 @@ import (
 
 type UpTestSuite struct {
 	suite.Suite
+
+	ctx context.Context
 }
 
 //nolint:paralleltest // can't parallel because of setenv
@@ -25,6 +27,10 @@ func TestUpTestSuite(t *testing.T) {
 	suite.Run(t, new(UpTestSuite))
 }
 
+func (ts *UpTestSuite) SetupTest() {
+	ts.ctx = tests.GetContext(ts.T())
+}
+
 func (ts *UpTestSuite) TestCmd() {
 	s := &Up{}
 	cmd := s.Cmd()
@@ -55,5 +61,5 @@ func (ts *UpTestSuite) TestAutoBuild() {
 	value := strings.ToLower(strings.ReplaceAll(ts.T().Name(), "/", ""))
 	ts.T().Setenv("NAMESPACE", value)
 
-	ts.Require().NoError(u.Run(context.Background()))
+	ts.Require().NoError(u.Run(ts.ctx))
 }
