@@ -9,6 +9,7 @@ import (
 	"time"
 
 	"github.com/gofrs/flock"
+	"github.com/helmwave/helmwave/pkg/clictx"
 	"github.com/helmwave/helmwave/pkg/helper"
 	"github.com/helmwave/helmwave/pkg/kubedog"
 	"github.com/helmwave/helmwave/pkg/monitor"
@@ -28,51 +29,50 @@ import (
 )
 
 // Up syncs repositories and releases.
-func (p *Plan) Up(ctx context.Context, dog *kubedog.Config) error {
+func (p *Plan) Up(ctx context.Context, dog *kubedog.Config) (err error) {
 	// Run hooks
-	err := p.body.Lifecycle.RunPreUp(ctx)
+	err = p.body.Lifecycle.RunPreUp(ctx)
 	if err != nil {
-		return err
+		return
 	}
 
 	defer func() {
-		err := p.body.Lifecycle.RunPostUp(ctx)
-		if err != nil {
-			log.Errorf("got an error from postup hooks: %v", err)
+		lifecycleErr := p.body.Lifecycle.RunPostUp(ctx)
+		if lifecycleErr != nil {
+			log.Errorf("got an error from postup hooks: %v", lifecycleErr)
+			if err == nil {
+				err = lifecycleErr
+			}
 		}
 	}()
 
 	log.Info("🗄 sync repositories...")
 	err = SyncRepositories(ctx, p.body.Repositories)
 	if err != nil {
-		return err
+		return
 	}
 
 	log.Info("🗄 sync registries...")
 	err = p.syncRegistries(ctx)
 	if err != nil {
-		return err
+		return
 	}
 
 	if len(p.body.Releases) == 0 {
-		return nil
+		return
 	}
 
 	log.Info("🛥 sync releases...")
 
 	if dog.Enabled {
 		log.Warn("🐶 kubedog is enabled")
-		kubedog.FixLog(dog.LogWidth)
+		kubedog.FixLog(ctx, dog.LogWidth)
 		err = p.syncReleasesKubedog(ctx, dog)
 	} else {
 		err = p.syncReleases(ctx)
 	}
 
-	if err != nil {
-		return err
-	}
-
-	return nil
+	return
 }
 
 func (p *Plan) syncRegistries(ctx context.Context) (err error) {
@@ -160,8 +160,7 @@ func SyncRepositories(ctx context.Context, repositories repo.Configs) error {
 func (p *planBody) generateDependencyGraph() (*dependency.Graph[uniqname.UniqName, release.Config], error) {
 	dependenciesGraph := dependency.NewGraph[uniqname.UniqName, release.Config]()
 
-	for i := range p.Releases {
-		rel := p.Releases[i]
+	for _, rel := range p.Releases {
 		err := dependenciesGraph.NewNode(rel.Uniq(), rel)
 		if err != nil {
 			return nil, err
@@ -181,7 +180,7 @@ func (p *planBody) generateDependencyGraph() (*dependency.Graph[uniqname.UniqNam
 }
 
 func getParallelLimit(ctx context.Context, releases release.Configs) int {
-	parallelLimit, ok := ctx.Value("parallel-limit").(int)
+	parallelLimit, ok := clictx.GetFlagFromContext(ctx, "parallel-limit").(int)
 	if !ok {
 		parallelLimit = 0
 	}
@@ -242,7 +241,7 @@ func (p *Plan) syncReleases(ctx context.Context) (err error) {
 
 	releasesMutex := &sync.Mutex{}
 
-	for i := 0; i < parallelLimit; i++ {
+	for range parallelLimit {
 		go p.syncReleasesWorker(ctx, releasesWG, releasesNodesChan, releasesMutex, releasesFails, monitorsLockMap)
 	}
 
@@ -301,11 +300,11 @@ func (p *Plan) syncRelease(
 
 	l.Info("🛥 deploying... ")
 
-	if _, err := rel.Sync(ctx); err != nil {
+	if _, err := rel.Sync(ctx, true); err != nil {
 		l.WithError(err).Error("❌ failed to deploy")
 
 		if rel.AllowFailure() {
-			l.Errorf("release is allowed to fail, markind as succeeded to dependencies")
+			l.Errorf("release is allowed to fail, marked as succeeded to dependencies")
 			node.SetSucceeded()
 		} else {
 			node.SetFailed()
